# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"Credentials": "01_environment.ipynb",
         "NifiEndpoint": "01_environment.ipynb",
         "DataFlowIds": "01_environment.ipynb",
         "Processor": "02_rest.ipynb",
         "Flowfiles": "02_rest.ipynb",
         "DataFlow": "03_dataflow.ipynb",
         "NifiIds": "04_source_to_refined.ipynb",
         "source_to_refined": "04_source_to_refined.ipynb",
         "custom_response": "09_tools.ipynb",
         "is_valid_csv": "09_tools.ipynb",
         "get_valid_names_in_connector": "09_tools.ipynb"}

modules = ["environment.py",
           "rest.py",
           "dataflow.py",
           "source_to_refined.py",
           "tools.py"]

doc_url = "https://kikejimenez.github.io/nifi_api/"

git_url = "https://github.com/kikejimenez/nifi_api/tree/main/"

def custom_doc_links(name): return None
